@@ -6,6 +6,7 @@ from redis.client import list_or_args
 from redis.exceptions import DataError
 from .conventions import RedizConventions, REDIZ_CONVENTIONS_ARGS, KeyList, NameList, ValueList
 from rediz.utilities import get_json_safe, has_nan, shorten, stem
+from pprint import pprint
 
 # REDIZ
 # -----
@@ -90,7 +91,7 @@ class Rediz(RedizConventions):
     def get_predictions(self, name, delay=None, delays=None):
         return self._get_predictions_implementation(name=name, delay=delay, delays=delays)
 
-    def get_cdf(self, name, delay=None, values=None, top=5, min_balance=0):
+    def get_cdf(self, name, delay=None, values=None, top=10, min_balance=-500):
         """
         :param values:   Abscissa for CDF
         :param top:      Number of top participants to use
@@ -874,7 +875,7 @@ class Rediz(RedizConventions):
         exec = expire_pipe.execute()
         report = dict( zip(all_names,exec) )
         self._confirm(write_key=write_key, operation='mtouch', count=sum(exec) )
-        if not all(exec):
+        if not any(exec):
             self._warn(write_key=write_key, operation='mtouch', error='expiry not set ... names may not exist', data=report, ttls=ttls )
         return sum(exec)
 
@@ -1214,7 +1215,6 @@ class Rediz(RedizConventions):
         assert name == self._root_name(name),"get_cdf expects root name"
         assert delay in self.DELAYS,"delay is not a valid choice of delay"
 
-        # We only use the top three performers on the leaderboard to estimate the inverse CDF
         score_pipe = self.client.pipeline()
         num = self.client.zcard(name=self._predictions_name(name=name, delay=delay))
         lb  = self._get_leaderboard_implementation(name=name,delay=delay,readable=False,count=top)
@@ -1325,7 +1325,7 @@ class Rediz(RedizConventions):
                 retrieve_pipe.smembers(self._sample_owners_name(name=name, delay=delay))    # List of owners
                 for window_ndx, window in enumerate(self._WINDOWS):
                     scenarios_lookup[name][delay_ndx][window_ndx] = len(retrieve_pipe)
-                    retrieve_pipe.zrangebyscore(name=samples_name, min=value - window, max=value + window, withscores=False, start=0, num=15)
+                    retrieve_pipe.zrangebyscore(name=samples_name, min=value - window, max=value + window, withscores=False, start=0, num=25)
                     # FIXME: This introduces bias toward selecting the bottom of the bucket ... do we want to make two calls instead?
         retrieved = retrieve_pipe.execute()
 
@@ -1466,7 +1466,6 @@ class Rediz(RedizConventions):
         else:
             return mean_prctl
 
-
     def _game_payments(self, pool, participant_set, rewarded_scenarios ):
         game_payments = Counter(dict((p, -1.0) for p in participant_set))
 
@@ -1482,7 +1481,12 @@ class Rediz(RedizConventions):
         if abs(sum(game_payments.values())) > 0.1:
             # This can occur if owners gets out of sync with the scenario hash ... which it should not
             # FIXME: Fail gracefully and raise system alert and/or garbage cleanup of owner::samples::delay::name versus samples::delay::name
-            raise Exception("Leakage in zero sum game")
+            print('********************************************')
+            print("Leakage in zero sum game",flush=True)
+            pprint(game_payments)
+            print('********************************************')
+            print('Set all payments to zero, for now, but need to fix this...')
+            game_payments = Counter(dict((p, 0.0) for p in participant_set))
         return game_payments
 
 
