@@ -107,7 +107,7 @@ class RedizConventions(MicroConventions):
         self._DEFAULT_MODEL_STD = 1.0  # Noise added for self-prediction
         self._WINDOWS = windows  # Sizes of neighbourhoods around truth used in countback ... don't make too big or it hits performance
         self._INSTANT_RECALL = instant_recall or False
-        self._MAX_TTL = int( max_ttl or 60 * 60 ) # Maximum TTL, useful for testing
+        self._MAX_TTL = int( max_ttl or 12*60*60 ) # Maximum TTL, useful for testing
         self._TRANSACTIONS_TTL = int( transactions_ttl or 24 * (60 * 60) )  # How long to keep transactions stream for inactive write_keys
         self._LEADERBOARD_TTL  = int( 24 * (60 * 60)*60 )  # How long to keep transactions stream for inactive write_keys
 
